@@ -2,7 +2,7 @@ package PDF::Tiny;
 
 use 5.01;
 
-$VERSION = '0.01'; # Update the POD, too!
+$VERSION = '0.02'; # Update the POD, too!
 
 # Fields
 sub vers () { 0 }
@@ -159,12 +159,16 @@ sub page_count {
 
 sub _walk_pages {
 	my $self = shift;
-	my $pages = shift || $self->get_obj("/Root", "/Pages", "/Kids")
+	my $pages = shift || $self->get_obj("/Root", "/Pages")
 	                  || return wantarray ? () : 0;
 	my @pages;		# output
+	my $kids = $self->get_obj($pages, "/Kids");
+	if ($self->get_obj($pages, "/Count")->[1] == @{$$kids[1]}) {
+         return @{$$kids[1]}
+	}
 	my $kid;
-	for (0 .. $#{$$pages[1]}){
-		$kid = $$pages[1][$_];
+	for (0 .. $#{$$kids[1]}){
+		$kid = $$kids[1][$_];
 		push @pages, ${$self->get_obj($kid, '/Type')}[1] eq 'Pages'
 			? _walk_pages($self->get_obj($$kid[1], '/Kids'))
 			: $kid;
@@ -229,7 +233,7 @@ sub import_page {
 }
 sub _flatten_pages {
  my ($self, $pages_id, $pages, $pages_array) = @ '_;
- my @pages = _walk_pages($self, $pages_array);
+ my @pages = _walk_pages($self, $pages);
  for (@pages) {
   my $page = $self->get_obj($_);
   next if $page->[1]{Parent}[1] eq $pages_id;
